import 'package:flutter/material.dart';
import 'package:question_frame/src/model/question.dart';
import 'package:question_frame/src/model/user_response.dart';
import 'package:question_frame/src/post_validator.dart';
import 'package:question_frame/src/pre_validator.dart';
import 'package:question_frame/src/widget/question_widget.dart';

class FrameWidget extends StatefulWidget {
  final Map<FrameQuestion, FrameUserResponse> questionResponseMap;

  const FrameWidget({Key? key, required this.questionResponseMap})
      : super(key: key);

  @override
  State<FrameWidget> createState() => _FrameWidgetState();
}

class _FrameWidgetState extends State<FrameWidget> {
  final PageController pageController = PageController();
  final PreValidator preValidator = PreValidator();
  final PostValidator postValidator = PostValidator();
  final Duration pageTransitionDuration = Duration(seconds: 1);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: PageView.builder(
        physics: const NeverScrollableScrollPhysics(),
        controller: pageController,
        itemCount: widget.questionResponseMap.length,
        itemBuilder: (context, index) {
          final entry = widget.questionResponseMap.entries.toList()[index];
          final validatedEntry = preValidator.preValidate(entry);
          return QuestionWidget(
            swipeLeft: swipeLeft,
            swipeRight: swipeRight,
            child: Container(
              color: index % 2 == 0 ? Colors.red : Colors.amber,
              child: Center(
                child: Text('$index'),
              ),
            ),
            question: validatedEntry.key,
            response: validatedEntry.value,
          );
        },
      ),
    );
  }

  void swipeLeft() {
    pageController.nextPage(
        duration: pageTransitionDuration, curve: Curves.ease);
  }

  void swipeRight() {
    pageController.previousPage(
        duration: pageTransitionDuration, curve: Curves.ease);
  }
}
