import 'package:json_annotation/json_annotation.dart';

import 'option.dart';
part 'question.g.dart';

@JsonSerializable(explicitToJson: true)
class FrameQuestion {
  @JsonKey(name: 'qid')
  final int id;

  @JsonKey(name: 'mid')
  final int mId;

  @JsonKey(name: 'gkey', defaultValue: '')
  final String qKey;

  @JsonKey(name: 'label')
  final String qLabel;

  @JsonKey(name: 'type')
  final String qType;

  @JsonKey(name: 'mandatory')
  final bool qMandatory;

  @JsonKey(name: 'mandatoryMsg', defaultValue: '')
  final String mandatoryMessage;

  @JsonKey(name: 'onLoad', defaultValue: '')
  final String onLoad;

  @JsonKey(name: 'onLoadMsg', defaultValue: '')
  final String onLoadMsg;

  @JsonKey(name: 'onActivity', defaultValue: '')
  final String onActivity;

  @JsonKey(name: 'onActivityMsg', defaultValue: '')
  final String onActivityMsg;

  @JsonKey(name: 'image', defaultValue: '')
  final String qImage;

  @JsonKey(name: 'audio', defaultValue: '')
  final String qAudio;

  @JsonKey(name: 'video', defaultValue: '')
  final String qVideo;

  @JsonKey(name: 'hint', defaultValue: '')
  final String qHint;

  @JsonKey(name: 'options')
  final List<FrameOption> options;
  FrameQuestion(
      {required this.id,
      required this.mId,
      required this.qKey,
      required this.qLabel,
      required this.qType,
      required this.qMandatory,
      required this.mandatoryMessage,
      required this.onLoad,
      required this.onLoadMsg,
      required this.onActivity,
      required this.onActivityMsg,
      required this.qImage,
      required this.qAudio,
      required this.qVideo,
      required this.options,
      required this.qHint});

  String getKey() {
    return 'm_${mId}_q_$id';
  }

  FrameQuestion copyWith({
    int? id,
    int? mId,
    String? qKey,
    String? qLabel,
    String? qType,
    int? qStatus,
    bool? qMandatory,
    String? mandatoryMessage,
    String? onLoad,
    String? onLoadMsg,
    String? onActivity,
    String? onActivityMsg,
    String? qImage,
    String? qAudio,
    String? qVideo,
    String? remarks,
    String? qHint,
    List<FrameOption>? options,
  }) {
    return FrameQuestion(
      id: id ?? this.id,
      mId: mId ?? this.mId,
      qKey: qKey ?? this.qKey,
      qLabel: qLabel ?? this.qLabel,
      qType: qType ?? this.qType,
      qMandatory: qMandatory ?? this.qMandatory,
      mandatoryMessage: mandatoryMessage ?? this.mandatoryMessage,
      onLoad: onLoad ?? this.onLoad,
      onLoadMsg: onLoadMsg ?? this.onLoadMsg,
      onActivity: onActivity ?? this.onActivity,
      onActivityMsg: onActivityMsg ?? this.onActivityMsg,
      qImage: qImage ?? this.qImage,
      qAudio: qAudio ?? this.qAudio,
      qVideo: qVideo ?? this.qVideo,
      qHint: qHint ?? this.qHint,
      options: options ?? this.options,
    );
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is FrameQuestion &&
          runtimeType == other.runtimeType &&
          id == other.id &&
          mId == other.mId;

  @override
  int get hashCode => id.hashCode ^ mId.hashCode;

  factory FrameQuestion.fromJson(Map<String, dynamic> json) =>
      _$FrameQuestionFromJson(json);
  Map<String, dynamic> toJson() => _$FrameQuestionToJson(this);
}
